@@ -31,6 +31,31 @@ YEAR_PRECEEDING_WORDS = {
     "de": ["im", "jahr", "vor", "ab", "seit"],
 }
 
+# the dict key is regex
+ABBR_WORDS = {
+    "en": {
+        r"\ba\.m\.": "am",
+        r"\bp\.m\.": "pm",
+        r"\bmr[\. ]": "mister",
+        r"\bmrs[\. ]": "missus",
+        r"\bdr[\. ]": "doctor",
+        r"\bprof[\. ]": "professor",
+        r"\bcapt[\. ]": "captain",
+        r"\betc\b": "et cetera",
+        r"\bvs[\. ]": "versus",
+        r"\bdept\.": "department",
+        r"\bapprox\.": "approximately",
+        r"\best\.": "established",
+        r"\bmisc\.": "miscellaneous",
+        r"\be\.g\.": "for example",
+    },
+    "de": {
+        r"\bz\.B\. ": "zum Beispiel",
+        r"\bbzw\.": "beziehungsweise",
+        r"\busw\.": "und so weiter",
+    },
+}
+
 
 class BaseFormatter:
     def __init__(self, lang="en"):
@@ -118,7 +143,8 @@ class TextFormatter(BaseFormatter):
             elif c == "–":
                 c = "-"
 
-            if c == "%" or c == "&" or c == "/":
+            if c == "%" or c == "&" or c == "/" or c == ".":
+                # dot should be handled specially for abbr
                 is_valid = True
             elif (
                 c == "'"
@@ -163,6 +189,16 @@ class TextFormatter(BaseFormatter):
 
         word_list = []
         change_list = {}
+
+        # handle dot and abbr words first
+        # so it not confuses with period and illegal dots
+        for abbr, repl in ABBR_WORDS[self.lang].items():
+            for found in re.findall(abbr, text, flags=re.IGNORECASE):
+                change_list[found] = repl.upper() if self.return_upper_case else repl
+            text = re.sub(abbr, repl + " ", text, flags=re.IGNORECASE)
+
+        text = text.replace(".", " ")
+
         text_iter = text.split()
         for idx, word in enumerate(text_iter):
             if not word:
@@ -170,7 +206,6 @@ class TextFormatter(BaseFormatter):
 
             to_append = None
 
-            # keep word as it will be in the change list
             if (
                 len(word) == 4
                 and word.isdigit()
